@@ -16,7 +16,7 @@ mv geophar-$version $newdir
 
 removedFiles=""
 
-for f in jsMath jquery.js underscore.js sympy; do
+for f in jsMath jquery.js underscore.js sympy 7zS.sfx; do
     for found in $(find $newdir -name $f); do
 	removedFiles="$removedFiles $found"
     done
